==============
Changelog
==============

1.0.1 (2026-02-10)
------------------

* FIX: `typing_extensions` and `packaging` dependencies for all python versions.

1.0.0 (2025-12-31)
------------------

This is the first stable release with a non negligeable number of new features and
performance improvement:

* Checkpointing (start and stop mechanisms)
* On-the-fly modification of the objective function
* Added benchmarks with scipy
* Provide an optional numba jit implementation for the expensive parts of the code.
* Enhanced documentation and tests.

0.1.1 (2024-06-29)
------------------

* First release on PyPI.
